==> account_kit-3.0.5.tar.gz: lib/ui/containers/signupContainer.dart <==
import 'package:account_kit/entities/user/user.dart';
import 'package:account_kit/redux/accountKitState.dart';
import 'package:account_kit/redux/user/userActions.dart';
import 'package:account_kit/ui/views/signupForm.dart';
import 'package:flutter/material.dart';
import 'package:flutter_redux/flutter_redux.dart';
import 'package:redux/redux.dart';

class SignupContainer<T extends VirtualAccountState> extends StatelessWidget {
  final Widget? header;
  final Widget? footer;
  final Widget? illustration;
  final Widget? validateEmailIllustration;
  final String subtitle;
  final String bottomInstructions;
  final Function? showSignin;
  final String signinInstructions;
  final String? defaultOrganizationToken;

  SignupContainer({
    this.header,
    this.footer,
    this.illustration,
    this.validateEmailIllustration,
    this.subtitle = "Create your account",
    this.bottomInstructions =
        "By tapping Create Account, you have read and agree to our Policies. Visit our website for more information.",
    this.signinInstructions = "Already have an account? Signin",
    this.showSignin,
    this.defaultOrganizationToken,
  });
  final String title = "Signup";
  @override
  Widget build(BuildContext context) {
    return StoreConnector<T, _ViewModel>(
      converter: (Store<T> store) => _ViewModel.create(store),
      builder: (BuildContext context, _ViewModel vm) =>
          _createBody(context, vm),
    );
  }

  Widget _createBody(BuildContext context, _ViewModel vm) {
    Widget body = Container(
      width: MediaQuery.of(context).size.width - 40 > 600
          ? 600
          : MediaQuery.of(context).size.width - 40,
      child: Wrap(
        alignment: WrapAlignment.center,
        runSpacing: 10.0,
        children: [
          illustration ?? Text(""),
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(
                subtitle,
                style: Theme.of(context).textTheme.bodyText1,
              ),
            ],
          ),
          (SignupForm<T>(
            defaultOrganizationToken: defaultOrganizationToken,
          )),
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Container(
                width: MediaQuery.of(context).size.width - 40,
                child: Text(
                  bottomInstructions,
                  textAlign: TextAlign.center,
                  style: Theme.of(context).textTheme.caption,
                ),
              ),
            ],
          ),
          Divider(),
          if (showSignin != null)
            GestureDetector(
              onTap: () {
                Navigator.of(context).pop();
                vm.clearUserRequest();
                showSignin!();
              },
              child: Text(signinInstructions,
                  textAlign: TextAlign.center,
                  style: Theme.of(context).textTheme.subtitle1!.merge(
                        TextStyle(fontWeight: FontWeight.bold),
                      )),
            ),
        ],
      ),
    );

    // if (vm.user != null) {
    //   body = Container(
    //     width: MediaQuery.of(context).size.width - 20,
    //     child: Column(
    //       children: [
    //         Padding(
    //           padding: const EdgeInsets.only(bottom: 12.0, top: 30),
    //           child: validateEmailIllustration ?? Text(""),
    //         ),
    //         Text(
    //           "Almost done, ${vm.user.firstName}!",
    //           style: Theme.of(context)
    //               .textTheme
    //               .headline5
    //               .merge(TextStyle(fontWeight: FontWeight.bold)),
    //         ),
    //         Text(
    //           "Check your mailbox ${vm.user.email}. You have received a link to validate your account. Click on it and then go back to the app to sign in.",
    //           textAlign: TextAlign.center,
    //         ),
    //         Padding(
    //           padding: const EdgeInsets.only(top: 12.0),
    //           child: RaisedButton(
    //             onPressed: () => Navigator.of(context).pop(),
    //             color: Theme.of(context).accentColor,
    //             child: Text(
    //               "Got it!",
    //               style: TextStyle(color: Colors.white),
    //             ),
    //           ),
    //         ),
    //         GestureDetector(
    //           onTap: vm.signout,
    //           child: Opacity(
    //             opacity: 0.7,
    //             child: Padding(
    //               padding: const EdgeInsets.only(top: 12.0),
    //               child: Text(
    //                 "Restart the signup process",
    //                 style: Theme.of(context).textTheme.caption,
    //               ),
    //             ),
    //           ),
    //         )
    //       ],
    //     ),
    //   );
    // }

    return Padding(
      padding: const EdgeInsets.only(top: 30.0),
      child: ListView(
        children: [
          Stack(
            children: [
              if (header != null)
                Positioned(
                    left: 0.0,
                    top: 0.0,
                    child: new Container(
                        width: MediaQuery.of(context).size.width,
                        decoration:
                            new BoxDecoration(color: Colors.grey.shade300),
                        child: header)),
              if (footer != null)
                Positioned(
                    left: 0.0,
                    bottom: 0.0,
                    child: new Container(
                        width: MediaQuery.of(context).size.width,
                        decoration:
                            new BoxDecoration(color: Colors.grey.shade300),
                        child: footer)),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(20.0),
                    child: Center(
                      child: body,
                    ),
                  ),
                ],
              ),
            ],
          ),
        ],
      ),
    );
  }
}

class _ViewModel {
  final User? user;
  final Function signout;
  final Function() clearUserRequest;
  _ViewModel(this.user, this.signout, this.clearUserRequest);

  factory _ViewModel.create(Store<VirtualAccountState> store) {
    return _ViewModel(
      store.state.accountKitState.userState.user,
      () => store.dispatch(SignOutAction(store.state.networkState.token)),
      () => store.dispatch(ClearUserRequestAction()),
    );
  }
}

==> account_kit-3.0.8.tar.gz: lib/ui/containers/signupContainer.dart <==
import 'package:account_kit/entities/user/user.dart';
import 'package:account_kit/redux/accountKitState.dart';
import 'package:account_kit/redux/user/userActions.dart';
import 'package:account_kit/ui/views/signupForm.dart';
import 'package:flutter/material.dart';
import 'package:flutter_redux/flutter_redux.dart';
import 'package:redux/redux.dart';

class SignupContainer<T extends VirtualAccountState> extends StatelessWidget {
  final Widget? header;
  final Widget? footer;
  final Widget? illustration;
  final Widget? validateEmailIllustration;
  final String subtitle;
  final String bottomInstructions;
  final Function? showSignin;
  final String signinInstructions;
  final String? defaultOrganizationToken;

  SignupContainer({
    this.header,
    this.footer,
    this.illustration,
    this.validateEmailIllustration,
    this.subtitle = "Create your account",
    this.bottomInstructions =
        "By tapping Create Account, you have read and agree to our Policies. Visit our website for more information.",
    this.signinInstructions = "Already have an account? Signin",
    this.showSignin,
    this.defaultOrganizationToken,
  });
  final String title = "Signup";
  @override
  Widget build(BuildContext context) {
    return StoreConnector<T, _ViewModel>(
      converter: (Store<T> store) => _ViewModel.create(store),
      builder: (BuildContext context, _ViewModel vm) =>
          _createBody(context, vm),
    );
  }

  Widget _createBody(BuildContext context, _ViewModel vm) {
    Widget body = Container(
      width: MediaQuery.of(context).size.width - 40 > 600
          ? 600
          : MediaQuery.of(context).size.width - 40,
      child: Wrap(
        alignment: WrapAlignment.center,
        runSpacing: 10.0,
        children: [
          illustration ?? Text(""),
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(
                subtitle,
                style: Theme.of(context).textTheme.bodyText1,
              ),
            ],
          ),
          (SignupForm<T>(
            defaultOrganizationToken: defaultOrganizationToken,
          )),
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Container(
                width: MediaQuery.of(context).size.width - 40,
                child: Text(
                  bottomInstructions,
                  textAlign: TextAlign.center,
                  style: Theme.of(context).textTheme.caption,
                ),
              ),
            ],
          ),
          Divider(),
          if (showSignin != null)
            GestureDetector(
              onTap: () {
                Navigator.of(context).pop();
                vm.clearSessionRequest();
                showSignin!();
              },
              child: Text(signinInstructions,
                  textAlign: TextAlign.center,
                  style: Theme.of(context).textTheme.subtitle1!.merge(
                        TextStyle(fontWeight: FontWeight.bold),
                      )),
            ),
        ],
      ),
    );

    // if (vm.user != null) {
    //   body = Container(
    //     width: MediaQuery.of(context).size.width - 20,
    //     child: Column(
    //       children: [
    //         Padding(
    //           padding: const EdgeInsets.only(bottom: 12.0, top: 30),
    //           child: validateEmailIllustration ?? Text(""),
    //         ),
    //         Text(
    //           "Almost done, ${vm.user.firstName}!",
    //           style: Theme.of(context)
    //               .textTheme
    //               .headline5
    //               .merge(TextStyle(fontWeight: FontWeight.bold)),
    //         ),
    //         Text(
    //           "Check your mailbox ${vm.user.email}. You have received a link to validate your account. Click on it and then go back to the app to sign in.",
    //           textAlign: TextAlign.center,
    //         ),
    //         Padding(
    //           padding: const EdgeInsets.only(top: 12.0),
    //           child: RaisedButton(
    //             onPressed: () => Navigator.of(context).pop(),
    //             color: Theme.of(context).accentColor,
    //             child: Text(
    //               "Got it!",
    //               style: TextStyle(color: Colors.white),
    //             ),
    //           ),
    //         ),
    //         GestureDetector(
    //           onTap: vm.signout,
    //           child: Opacity(
    //             opacity: 0.7,
    //             child: Padding(
    //               padding: const EdgeInsets.only(top: 12.0),
    //               child: Text(
    //                 "Restart the signup process",
    //                 style: Theme.of(context).textTheme.caption,
    //               ),
    //             ),
    //           ),
    //         )
    //       ],
    //     ),
    //   );
    // }

    return Padding(
      padding: const EdgeInsets.only(top: 30.0),
      child: ListView(
        children: [
          Stack(
            children: [
              if (header != null)
                Positioned(
                    left: 0.0,
                    top: 0.0,
                    child: new Container(
                        width: MediaQuery.of(context).size.width,
                        decoration:
                            new BoxDecoration(color: Colors.grey.shade300),
                        child: header)),
              if (footer != null)
                Positioned(
                    left: 0.0,
                    bottom: 0.0,
                    child: new Container(
                        width: MediaQuery.of(context).size.width,
                        decoration:
                            new BoxDecoration(color: Colors.grey.shade300),
                        child: footer)),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(20.0),
                    child: Center(
                      child: body,
                    ),
                  ),
                ],
              ),
            ],
          ),
        ],
      ),
    );
  }
}

class _ViewModel {
  final User? user;
  final Function signout;
  final Function() clearSessionRequest;

  _ViewModel(
    this.user,
    this.signout,
    this.clearSessionRequest,
  );

  factory _ViewModel.create(Store<VirtualAccountState> store) {
    return _ViewModel(
      store.state.accountKitState.userState.user,
      () => store.dispatch(SignOutAction(store.state.networkState.token)),
      () => store.dispatch(ClearSessionRequestAction()),
    );
  }
}
